<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh-CN" sourcelanguage="en">
  <context>
    <name>AssemblyGui::Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+50"/>
      <source>Assembly</source>
      <translation>装配</translation>
    </message>
  </context>
  <context>
    <name>CmdAssemblyConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="+42"/>
      <source>Assembly</source>
      <translation>装配</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Constraint Axle...</source>
      <translation>约束轴...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>set a axle constraint between two objects</source>
      <translation>两个对象之间设置轴约束</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Assembly</source>
      <translation type="obsolete">装配</translation>
    </message>
  </context>
</TS>
